<?php

/*
 * Copyright (C) 2016 Champs-Libres <info@champs-libres.coop>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

namespace Chill\ActivityBundle\Export\Aggregator;

use Symfony\Component\Form\FormBuilderInterface;
use Doctrine\ORM\QueryBuilder;
use Chill\MainBundle\Export\AggregatorInterface;
use Symfony\Component\Security\Core\Role\Role;
use Chill\ActivityBundle\Security\Authorization\ActivityStatsVoter;
use Doctrine\ORM\EntityRepository;
use Chill\MainBundle\Templating\TranslatableStringHelper;
use Doctrine\ORM\Query\Expr\Join;

/**
 * 
 *
 * @author Julien Fastré <julien.fastre@champs-libres.coop>
 */
class ActivityTypeAggregator implements AggregatorInterface
{
    
    /**
     *
     * @var EntityRepository
     */
    protected $typeRepository;
    
    /**
     *
     * @var TranslatableStringHelper
     */
    protected $stringHelper;
    
    const KEY = 'activity_type_aggregator';
    
    public function __construct(
            EntityRepository $typeRepository,
            TranslatableStringHelper $stringHelper
    ) {
        $this->typeRepository     = $typeRepository;
        $this->stringHelper       = $stringHelper;
    }
    
    public function alterQuery(QueryBuilder $qb, $data)
    {
        // add select element    
        $qb->addSelect(sprintf('IDENTITY(activity.type) AS %s', self::KEY));
        
        // add the "group by" part
        $groupBy = $qb->addGroupBy(self::KEY);
    }
    
    /**
     * Check if a join between Activity and another alias
     * 
     * @param Join[] $joins
     * @param string $alias the alias to search for
     * @return boolean
     */
    private function checkJoinAlreadyDefined(array $joins, $alias)
    {
        foreach ($joins as $join) {
            if ($join->getAlias() === $alias) {
                return true;
            }
        }
        
        return false;
    }

    public function applyOn()
    {
        return 'activity';
    }

    public function buildForm(FormBuilderInterface $builder)
    {
        // no form required for this aggregator
    }

    public function getTitle()
    {
        return "Aggregate by activity type";
    }
    
    public function addRole()
    {
        return new Role(ActivityStatsVoter::STATS);
    }

    public function getLabels($key, array $values, $data)
    {
        // for performance reason, we load data from db only once
        $this->typeRepository->findBy(array('id' => $values));
        
        return function($value) use ($data) {
            if ($value === '_header') {
                return 'Activity type';
            }

            /* @var $r \Chill\ActivityBundle\Entity\ActivityType */
            $t = $this->typeRepository->find($value);

            return $this->stringHelper->localize($t->getName());
        };
        
    }

    public function getQueryKeys($data)
    {
        return array(self::KEY);
    }

}
