<?php

/*
 * Copyright (C) 2015 Champs-Libres <info@champs-libres.coop>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

namespace Chill\ActivityBundle\Export\Export;

use Chill\MainBundle\Export\ExportInterface;
use Doctrine\ORM\QueryBuilder;
use Symfony\Component\Security\Core\Role\Role;
use Doctrine\ORM\Query;
use Chill\ActivityBundle\Security\Authorization\ActivityStatsVoter;
use Doctrine\ORM\EntityManagerInterface;

/**
 *
 *
 * @author Julien Fastré <julien.fastre@champs-libres.coop>
 */
class CountActivity implements ExportInterface
{
    /**
     *
     * @var EntityManagerInterface
     */
    protected $entityManager;
    
    public function __construct(
            EntityManagerInterface $em
            )
    {
        $this->entityManager = $em;
    }
    
    public function buildForm(\Symfony\Component\Form\FormBuilderInterface $builder)
    {
        
    }

    public function getDescription()
    {
        return "Count activities by various parameters.";
    }

    public function getTitle()
    {
        return "Count activities";
    }

    public function getType()
    {
        return 'activity';
    }

    public function initiateQuery(array $requiredModifiers,  array $acl, array $data = array())
    {
        $qb = $this->entityManager->createQueryBuilder();
        $centers = array_map(function($el) { return $el['center']; }, $acl);
        
        $qb->select('COUNT(activity.id) as export_count_activity')
                ->from('ChillActivityBundle:Activity', 'activity')
                ->join('activity.person', 'person')
                ;
        
        $qb->where($qb->expr()->in('person.center', ':centers'))
            ->setParameter('centers', $centers)
            ;
        
        return $qb;
    }
    
    public function supportsModifiers()
    {
        return array('person', 'activity');
    }
    
    public function requiredRole()
    {
        return new Role(ActivityStatsVoter::STATS);
    }

    public function getAllowedFormattersTypes()
    {
        return array(\Chill\MainBundle\Export\FormatterInterface::TYPE_TABULAR);
    }

    public function getLabels($key, array $values, $data)
    {
        if ($key !== 'export_count_activity') {
            throw new \LogicException("the key $key is not used by this export");
        }
        
        return function($value) {
            return $value === '_header' ? 
                    'Number of activities'
                    :
                    $value
                    ;
        };
    }

    public function getQueryKeys($data)
    {
        return array('export_count_activity');
    }

    public function getResult($qb, $data)
    {
        return $qb->getQuery()->getResult(Query::HYDRATE_SCALAR);
    }

}
