<?php

namespace Chill\PersonBundle\Controller;

use Chill\PersonBundle\Entity\AccompanyingPeriod;
use Chill\PersonBundle\Entity\AccompanyingPeriodParticipation;
use Chill\PersonBundle\Privacy\AccompanyingPeriodPrivacyEvent;
use Chill\PersonBundle\Entity\Person;
use Chill\PersonBundle\Security\Authorization\AccompanyingPeriodVoter;
use Sensio\Bundle\FrameworkExtraBundle\Configuration\ParamConverter;
use Symfony\Bundle\FrameworkBundle\Controller\Controller;
use Symfony\Component\HttpFoundation\JsonResponse;
use Symfony\Component\HttpFoundation\Response;
use Symfony\Component\HttpFoundation\Exception\BadRequestException;
use Symfony\Component\Routing\Annotation\Route;
use Symfony\Component\Serializer\Encoder\JsonEncoder;
use Symfony\Component\Serializer\Normalizer\AbstractObjectNormalizer;
use Symfony\Component\Serializer\Normalizer\ObjectNormalizer;
use Symfony\Component\Serializer\SerializerInterface;
use Symfony\Contracts\EventDispatcher\EventDispatcherInterface;
use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\Validator\Validator\ValidatorInterface;

/**
 * Class AccompanyingCourseController
 *
 * @package Chill\PersonBundle\Controller
 */
class AccompanyingCourseController extends Controller
{
    protected SerializerInterface $serializer;

    protected EventDispatcherInterface $dispatcher;

    protected ValidatorInterface $validator;

    public function __construct(
        SerializerInterface $serializer,
        EventDispatcherInterface $dispatcher,
        ValidatorInterface $validator
    ) {
        $this->serializer = $serializer;
        $this->dispatcher = $dispatcher;
        $this->validator = $validator;
    }

    /**
     * @Route("/{_locale}/person/parcours/new", name="chill_person_accompanying_course_new")
     */
    public function newAction(Request $request): Response
    {
        $period = new AccompanyingPeriod();
        $em = $this->getDoctrine()->getManager();

        if ($request->query->has('person_id')) {
            $personIds = $request->query->get('person_id');

            if (FALSE === \is_array($personIds)) {
                throw new BadRequestException("person_id parameter should be an array");
            }

            foreach ($personIds as $personId) {
                $person = $em->getRepository(Person::class)->find($personId);
                if (NULL !== $person) {
                    $period->addPerson($person);
                }
            }
        }

        $this->denyAccessUnlessGranted(AccompanyingPeriodVoter::SEE, $period);

        $em->persist($period);
        $em->flush();

        return $this->redirectToRoute('chill_person_accompanying_course_show', [
            'accompanying_period_id' => $period->getId()
        ]);
         
    }

    /**
     * Homepage of Accompanying Course section
     *
     * @Route("/{_locale}/parcours/{accompanying_period_id}", name="chill_person_accompanying_course_index")
     * @ParamConverter("accompanyingCourse", options={"id": "accompanying_period_id"})
     */
    public function indexAction(AccompanyingPeriod $accompanyingCourse): Response
    {
        return $this->render('@ChillPerson/AccompanyingCourse/index.html.twig', [
            'accompanyingCourse' => $accompanyingCourse
        ]);
    }

    /**
     * Show page of Accompanying Course section
     *
     * the page show all blocks except one active edit block, managed by vuejs component
     * that's why title of page is 'edit accompanying course'
     *
     * @Route("/{_locale}/parcours/{accompanying_period_id}/show", name="chill_person_accompanying_course_show")
     * @ParamConverter("accompanyingCourse", options={"id": "accompanying_period_id"})
     */
    public function showAction(AccompanyingPeriod $accompanyingCourse): Response
    {
        return $this->render('@ChillPerson/AccompanyingCourse/show.html.twig', [
            'accompanyingCourse' => $accompanyingCourse
        ]);
    }

    /**
     * History page of Accompanying Course section
     *
     * the page show anti chronologic history with all actions, title of page is 'accompanying course details'
     *
     * @Route("/{_locale}/parcours/{accompanying_period_id}/history", name="chill_person_accompanying_course_history")
     * @ParamConverter("accompanyingCourse", options={"id": "accompanying_period_id"})
     */
    public function historyAction(AccompanyingPeriod $accompanyingCourse): Response
    {
        return $this->render('@ChillPerson/AccompanyingCourse/history.html.twig', [
            'accompanyingCourse' => $accompanyingCourse
        ]);
    }

}
