import 'es6-promise/auto';
import { createStore } from 'vuex';
import { getAccompanyingCourse, 
   patchAccompanyingCourse,
   confirmAccompanyingCourse,
   postParticipation, 
   postRequestor,
   postResource,
   postSocialIssue } from '../api';

const debug = process.env.NODE_ENV !== 'production';
const id = window.accompanyingCourseId;

let initPromise = getAccompanyingCourse(id)
   .then(accompanying_course => new Promise((resolve, reject) => {
            
      const store = createStore({
         strict: debug,
         modules: {
         },
         state: {
            accompanyingCourse: accompanying_course,
            errorMsg: []
         },
         getters: {
         },
         mutations: {
            catchError(state, error) {
               state.errorMsg.push(error); 
            },
            removeParticipation(state, participation) {
               //console.log('### mutation: remove participation', participation.id);
               state.accompanyingCourse.participations = state.accompanyingCourse.participations.filter(element => element !== participation);
            },
            closeParticipation(state, { participation, payload }) {
               //console.log('### mutation: close item', { participation, payload });
               // find row position and replace by closed participation
               state.accompanyingCourse.participations.splice(
                  state.accompanyingCourse.participations.findIndex(element => element === payload), 1, participation
               );
            },
            addParticipation(state, participation) {
               //console.log('### mutation: add participation', participation);
               state.accompanyingCourse.participations.push(participation);
            },
            removeRequestor(state) {
               //console.log('### mutation: removeRequestor');
               state.accompanyingCourse.requestor = null;
            },
            addRequestor(state, requestor) {
               //console.log('### mutation: addRequestor', requestor);
               state.accompanyingCourse.requestor = requestor;
            },
            requestorIsAnonymous(state, value) {
               //console.log('### mutation: requestorIsAnonymous', value);
               state.accompanyingCourse.requestorAnonymous = value;
            },
            removeResource(state, resource) {
               //console.log('### mutation: removeResource', resource);
               state.accompanyingCourse.resources = state.accompanyingCourse.resources.filter(element => element !== resource);
            },
            addResource(state, resource) {
               //console.log('### mutation: addResource', resource);
               state.accompanyingCourse.resources.push(resource);
            },
            toggleIntensity(state, value) {
               state.accompanyingCourse.intensity = value;
            },
            toggleEmergency(state, value) {
               //console.log('### mutation: toggleEmergency');
               state.accompanyingCourse.emergency = value;
            },
            toggleConfidential(state, value) {
               //console.log('### mutation: toggleConfidential');
               state.accompanyingCourse.confidential = value;
            },
            postFirstComment(state, comment) {
               //console.log('### mutation: postFirstComment', comment);
               state.accompanyingCourse.initialComment = comment;
            }, 
            updateSocialIssues(state, value) {
               state.accompanyingCourse.socialIssues = value;
            },
            confirmAccompanyingCourse(state, response) {
               //console.log('### mutation: confirmAccompanyingCourse: response', response);
               state.accompanyingCourse.step = response.step;
            }
         },
         actions: {
            removeParticipation({ commit }, payload) {
               commit('removeParticipation', payload);
               // fetch DELETE request...
            },
            closeParticipation({ commit }, payload) {
               //console.log('## action: fetch delete participation: payload', payload);
               postParticipation(id, payload.person, 'DELETE')
               .then(participation => new Promise((resolve, reject) => {
                  commit('closeParticipation', { participation, payload });
                  resolve();
               })).catch((error) => { commit('catchError', error) }); 
            },
            addParticipation({ commit }, payload) {
               //console.log('## action: fetch post participation (select item): payload', payload);
               postParticipation(id, payload.result, 'POST')
               .then(participation => new Promise((resolve, reject) => {
                  commit('addParticipation', participation);
                  resolve();
               })).catch((error) => { commit('catchError', error) }); 
            },
            removeRequestor({ commit, dispatch }) {
               //console.log('## action: fetch delete requestor');
               postRequestor(id, null, 'DELETE')
               .then(requestor => new Promise((resolve, reject) => {
                  commit('removeRequestor');
                  dispatch('requestorIsAnonymous', false);
                  resolve();
               })).catch((error) => { commit('catchError', error) }); 
            },
            addRequestor({ commit }, payload) {
               //console.log('## action: fetch post requestor: payload', payload);
               postRequestor(id, payload.result, 'POST')
               .then(requestor => new Promise((resolve, reject) => {
                  commit('addRequestor', requestor);
                  resolve();
               })).catch((error) => { commit('catchError', error) }); 
            },
            requestorIsAnonymous({ commit }, payload) {
               //console.log('## action: fetch patch AccompanyingCourse: payload', payload);
               patchAccompanyingCourse(id, { type: "accompanying_period", requestorAnonymous: payload })
               .then(course => new Promise((resolve, reject) => {
                  commit('requestorIsAnonymous', course.requestorAnonymous)
                  resolve();
               })).catch((error) => { commit('catchError', error) });
            },
            removeResource({ commit }, payload) {
               //console.log('## action: fetch postResource: payload', payload);
               postResource(id, payload, 'DELETE')
               .then(resource => new Promise((resolve, reject) => {
                  commit('removeResource', payload) // mieux un retour de l'objet !
                  resolve();
               })).catch((error) => { commit('catchError', error) });
            },
            addResource({ commit }, payload) {
               //console.log('## action: fetch postResource: payload', payload);
               postResource(id, payload.result, 'POST')
               .then(resource => new Promise((resolve, reject) => {
                  commit('addResource', resource)
                  resolve();
               })).catch((error) => { commit('catchError', error) });
            },
            toggleIntensity({ commit }, payload) {
               //console.log(payload);
               patchAccompanyingCourse(id, { type: "accompanying_period", intensity: payload })
               .then(course => new Promise((resolve, reject) => {
                  commit('toggleIntensity', course.intensity);
                  resolve();
               })).catch((error) => { commit('catchError', error) });
            },
            toggleEmergency({ commit }, payload) {
               patchAccompanyingCourse(id, { type: "accompanying_period", emergency: payload })
               .then(course => new Promise((resolve, reject) => {
                  commit('toggleEmergency', course.emergency);
                  resolve();
               })).catch((error) => { commit('catchError', error) });
            },
            toggleConfidential({ commit }, payload) {
               patchAccompanyingCourse(id, { type: "accompanying_period", confidential: payload })
               .then(course => new Promise((resolve, reject) => {
                  commit('toggleConfidential', course.confidential);
                  resolve();
               })).catch((error) => { commit('catchError', error) });
            },
            postFirstComment({ commit }, payload) {
               //console.log('## action: postFirstComment: payload', payload);
               patchAccompanyingCourse(id, { type: "accompanying_period", initialComment: payload })
               .then(course => new Promise((resolve, reject) => {
                  commit('postFirstComment', course.initialComment);
                  resolve();
               })).catch((error) => { commit('catchError', error) });
            },
            updateSocialIssues({ commit }, { payload, body, method }) {
               //console.log('## action: payload', { payload, body, method });
               postSocialIssue(id, body, method)
               .then(response => new Promise((resolve, reject) => {
                  //console.log('response', response);
                  commit('updateSocialIssues', payload);
                  resolve();
               })).catch((error) => { commit('catchError', error) });
            },
            confirmAccompanyingCourse({ commit }) {
               //console.log('## action: confirmAccompanyingCourse');
               confirmAccompanyingCourse(id)
               .then(response => new Promise((resolve, reject) => {
                  commit('confirmAccompanyingCourse', response);
                  console.log('fetch resolve'); // redirection with #top anchor
                  resolve();
               })).catch((error) => { commit('catchError', error) });
            }
         }
      });
      resolve(store);
   }));

export { initPromise };
