<?php

namespace Chill\PersonBundle\Security\Authorization;

use Chill\MainBundle\Security\Authorization\AbstractChillVoter;
use Chill\MainBundle\Entity\User;
use Chill\MainBundle\Security\Authorization\AuthorizationHelper;
use Chill\MainBundle\Security\ProvideRoleHierarchyInterface;
use Chill\PersonBundle\Entity\Person;
use Chill\PersonBundle\Entity\AccompanyingPeriod;
use Chill\MainBundle\Entity\Center;
use Symfony\Component\Security\Core\Authentication\Token\TokenInterface;
use Symfony\Component\Security\Core\Role\Role;

class AccompanyingPeriodVoter extends AbstractChillVoter  implements ProvideRoleHierarchyInterface
{
    protected AuthorizationHelper $helper;

    public const SEE = 'CHILL_PERSON_ACCOMPANYING_PERIOD_SEE';

    /**
     * @param AuthorizationHelper $helper
     */
    public function __construct(AuthorizationHelper $helper)
    {
            $this->helper = $helper;
    }

    protected function supports($attribute, $subject)
    {
        return $subject instanceof AccompanyingPeriod;
    }

    protected function voteOnAttribute($attribute, $subject, TokenInterface $token)
    {
        if (!$token->getUser() instanceof User) {
            return false;
        }

        // TODO take scopes into account
        if (count($subject->getPersons()) === 0) {
            return true;
        }
        foreach ($subject->getPersons() as $person) {
            // give access as soon as on center is reachable
            if ($this->helper->userHasAccess($token->getUser(), $person->getCenter(), $attribute)) {
                return true;
            }

            return false;
        }
    }

    private function getAttributes()
    {
        return [
            self::SEE
        ];
    }

    public function getRoles()
    {
        return $this->getAttributes();
    }

    public function getRolesWithoutScope()
    {
        return [];
    }
    
    public function getRolesWithHierarchy()
    {
        return [ 'Person' => $this->getRoles() ];
    }

}
